==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>The plugin %1 is not compatible with the system.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Remove</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth settings</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Turn off</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Turn on</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth settings</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connected</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connecting...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Turned off</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Add keyboard layout</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datetime</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-hour time</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-hour time</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Time settings</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Enable network</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disable network</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Network settings</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Are you sure you want to empty %1 items?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>This action cannot be restored</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Unknown device</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Unknown volume</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Unmount all</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Launcher</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion Mode</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficient Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Top</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bottom</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Left</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Right</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Keep Shown</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Keep Hidden</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Smart Hide</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Location</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitasking View</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Undock</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Disable wired connection</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Enable wired connection</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disable wireless connection</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Enable wireless connection</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disable network</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Enable network</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Network settings</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Wireless connection: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Wired connection: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connection failed</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Wired Network %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Power</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Power settings</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacity %1, %2 min remaining</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacity %1, %2 hr %3 min remaining</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Charging %1, %2 min until full</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Charging %1, %2 hr %3 min until full</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Charged</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacity %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Charging %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacity %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacity %1, fully charged</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Show Desktop</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Undock</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Power</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Shut down</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernate</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lock</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log out</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Switch account</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Power settings</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Device</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Unmute</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Sound settings</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Trash</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Trash - %1 file</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Trash - %1 files</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Empty</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>System Tray</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Wireless Network %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>The plugin %1 is not compatible with the system.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Airplane Mode</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Airplane mode enabled</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Turn off</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Turn on</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Airplane Mode settings</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Airplane mode disabled</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Airplane Mode</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Remove</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth settings</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Turn off</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Turn on</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth settings</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connected</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connecting...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Turned off</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Add keyboard layout</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datetime</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-hour time</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-hour time</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Time settings</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Monday</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tuesday</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Wednesday</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Thursday</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Friday</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Saturday</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sunday</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>monday</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tuesday</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>wednesday</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>thursday</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>friday</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>saturday</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sunday</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation>%1year%2month%3day</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Are you sure you want to empty %1 items?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>This action cannot be restored</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Unknown device</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Unknown volume</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Unmount all</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Launcher</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Exit Safe Mode</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dock - Safe Mode</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>The Dock is in safe mode, please exit to show it properly</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion Mode</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficient Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Top</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bottom</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Left</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Right</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Keep Shown</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Keep Hidden</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Smart Hide</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Location</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Dock settings</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Size</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Multiple Displays</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Plugin Area</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Select which icons appear in the Dock</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Fashion mode</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Efficient mode</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Top</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bottom</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Left</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Right</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Location</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Keep shown</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Keep hidden</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Smart hide</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Show Dock</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>On screen where the cursor is</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Only on main screen</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitasking View</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Undock</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Power</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Power settings</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacity %1, %2 min remaining</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacity %1, %2 hr %3 min remaining</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Charging %1, %2 min until full</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Charging %1, %2 hr %3 min until full</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacity %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Charging %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacity %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacity %1, fully charged</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Location</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Size</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Show Dock</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Plugin Area</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Show Desktop</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Undock</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Power</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Shut down</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernate</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lock</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log out</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Switch account</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Power settings</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Unmute</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Sound settings</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>No output devices</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Trash</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Trash - %1 file</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Trash - %1 files</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Move to Trash</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Empty</translation>
    </message>
</context>
</TS>
